import axios from 'axios';
import DeviceRequest from '../models/DeviceRequest';
import {GetInfoDeviceResponse} from '../models/GetInfoDeviceResponse';
import WhoamiResponse from '../models/WhoamiResponse';
import {INFO_DEVICE_METHOD, WHOAMI_METHOD} from '../../consts/urls';
// import responseDevicesMock from './response-devices-mock.json';

const KEYAUTORIZACION = 'token';

class DevicesAPI {
  private baseURL: string;

  constructor(baseURL: string) {
    this.baseURL = baseURL;
  }

  async whoami({token, deviceId}: DeviceRequest): Promise<WhoamiResponse> {
    if (!token) {
      throw new Error('token is required');
    }

    if (!deviceId) {
      throw new Error('deviceId is required');
    }
    const {data} = await axios.post<WhoamiResponse>(
      `${this.baseURL}${WHOAMI_METHOD}`,
      {
        whoami: {idDispositivo: deviceId, KeyAuthorizacion: KEYAUTORIZACION},
      },
      {
        headers: {
          Authorization: `Bearer ${token}`,
        },
      },
    );

    return data;
  }

  async getInfoDevice({
    token,
    deviceId,
  }: DeviceRequest): Promise<GetInfoDeviceResponse> {
    if (!token) {
      throw new Error('token is required');
    }

    if (!deviceId) {
      throw new Error('deviceId is required');
    }

    const {data} = await axios.post<GetInfoDeviceResponse>(
      `${this.baseURL}${INFO_DEVICE_METHOD}`,
      {
        GetInfoDevice: {
          idDispositivo: deviceId,
          KeyAuthorizacion: KEYAUTORIZACION,
        },
      },
      {
        headers: {
          Authorization: `Bearer ${token}`,
        },
      },
    );

    return data; // rial implementation

    // return responseDevicesMock; // mock implementation
  }
}

export default DevicesAPI;
