import {renderHook, waitFor} from '@testing-library/react-native';
import useRemoteConfig from '../useRemoteConfig';
import Status from '../../../utils/Status';
import {
  setConfigSettings,
  setDefaults,
  fetchAndActivate,
  getString,
} from '../../../../__mocks__/@react-native-firebase/remote-config';

describe('useRemoteconfig tests', () => {
  it('should be defined', async () => {
    expect(useRemoteConfig).toBeDefined();
  });

  describe('on init hook', () => {
    beforeEach(() => {
      jest.clearAllMocks();
    });

    it('should load remote config data succesfully', async () => {
      fetchAndActivate.mockResolvedValueOnce(true);

      const {result} = renderHook(() => useRemoteConfig());

      expect(result.current.status).toBe(Status.LOADING);

      await waitFor(() => {
        expect(result.current.status).toBe(Status.SUCCESS);
        expect(setConfigSettings).toHaveBeenCalledTimes(1);
        expect(setDefaults).toHaveBeenCalledTimes(1);
        expect(fetchAndActivate).toHaveBeenCalledTimes(1);
      });
    });

    it('should fail to load remote config data', async () => {
      setConfigSettings.mockRejectedValueOnce(new Error('Error'));

      const {result} = renderHook(() => useRemoteConfig());

      expect(result.current.status).toBe(Status.LOADING);

      await waitFor(() => {
        expect(result.current.status).toBe(Status.ERROR);
        expect(setConfigSettings).toHaveBeenCalledTimes(1);
        expect(fetchAndActivate).toHaveBeenCalledTimes(0);
        expect(setDefaults).toHaveBeenCalledTimes(0);
      });
    });
  });
});
