import {Image, StyleSheet, View} from 'react-native';
import remoteConfig from '@react-native-firebase/remote-config';
import Container from '../components/Container';
import Header from '../components/Header';
import useDevices from '../../infraestructure/hooks/useDevices';
import Banner from '../components/Banner';
import RemoteConfigKeys from '../../utils/RemoteConfigKeys';
import BusList from '../components/BusList';

const BANNER_TEXT = 'Buses que se detienen en esta parada';

const BusStopInfoScreen = () => {
  const {
    state: {status, displayedLines, stopName},
  } = useDevices();

  const image = remoteConfig().getString(RemoteConfigKeys.HEADER_IMAGE_URL);

  const [first, second] = stopName.split('-');
  const title = first ? first.trim() : '';
  const subTitle = second ? second.trim() : '';

  return (
    <Container style={styles.container}>
      <Header
        style={styles.headerContainer}
        subTitle={subTitle}
        title={title}
        image={image}
      />
      <Banner style={styles.bannerContainer} text={BANNER_TEXT} />
      <BusList
        buses={displayedLines}
        style={styles.bodyContainer}
        status={status}
      />
      <View style={styles.headerContainer}>
        {/*footerContainer  <Image
          source={require('../../../resources/images/footer.jpg')}
          style={styles.image}
        /> */}
      </View>
    </Container>
  );
};

const styles = StyleSheet.create({
  container: {
    justifyContent: 'center',
  },
  containerCenter: {
    justifyContent: 'center',
    alignItems: 'center',
  },
  headerContainer: {
    flex: 1.5,
    backgroundColor: 'orange',
  },
  bannerContainer: {
    flex: 0.5,
    backgroundColor: 'orange',
  },
  bodyContainer: {
    flex: 10,
    justifyContent: 'center',
  },
  footerContainer: {
    flex: 1,
  },
  image: {
    flex: 1,
    width: '100%',
    height: '100%',
    resizeMode: 'stretch',
  },
});

export default BusStopInfoScreen;
