import {render} from '@testing-library/react-native';
import BusStopInfoScreen from '../BusStopInfoScreen';
import * as useDevices from '../../../infraestructure/hooks/useDevices';
import * as useRemoteConfig from '../../../infraestructure/hooks/useRemoteConfig';
import {getString} from '../../../../__mocks__/@react-native-firebase/remote-config';

const mockState: useDevices.State = {
  status: 1,
  currentIndex: 0,
  stopMessage: 'No considerar, uso futuro',
  displayedLines: [
    {
      backgroundColor: 'b10086',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'N',
      lineNumber: '10',
      lineDescription: 'Vía Láctea - Los Bloques',
      letterColor: '',
    },
    {
      backgroundColor: '0071ca',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'P',
      lineNumber: '10',
      lineDescription: 'Vía Láctea - Leonera',
      letterColor: '',
    },
    {
      backgroundColor: '4e0963',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'L',
      lineNumber: '10',
      lineDescription: 'Vía Láctea -  Los Bloques',
      letterColor: '',
    },
    {
      backgroundColor: 'ad0101',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'Q',
      lineNumber: '11',
      lineDescription: 'Vía Futuro -  Los Bloques',
      letterColor: '',
    },
    {
      backgroundColor: 'b10086',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'R',
      lineNumber: '11',
      lineDescription: 'Vía Futuro - Porvenir',
      letterColor: '',
    },
    {
      backgroundColor: 'ce5504',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'S',
      lineNumber: '13',
      lineDescription: 'Vía Siglo XXI - Leonera',
      letterColor: '',
    },
    {
      backgroundColor: 'ce5504',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'T',
      lineNumber: '14',
      lineDescription: 'Chiguayante Sur -  Coquimbo',
      letterColor: '',
    },
    {
      backgroundColor: 'cc9b00',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'U',
      lineNumber: '14',
      lineDescription: 'Chiguayante Sur -  Los Altos',
      letterColor: '',
    },
    {
      backgroundColor: 'ce5504',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'K',
      lineNumber: '16',
      lineDescription: 'Vía Universo - Leonera',
      letterColor: '',
    },
    {
      backgroundColor: 'ad0101',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'V',
      lineNumber: '16',
      lineDescription: 'Vía Universo - Leonera',
      letterColor: '',
    },
    {
      backgroundColor: '0d7215',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'W',
      lineNumber: '17',
      lineDescription: 'Expresos Chiguayante - Leonera',
      letterColor: '',
    },
    {
      backgroundColor: 'ce5504',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'X',
      lineNumber: '17',
      lineDescription: 'Expresos Chiguayante - Leonera',
      letterColor: '',
    },
    {
      backgroundColor: '0071ca',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'Y',
      lineNumber: '18',
      lineDescription: 'Buses Palomares -  Hualqui',
      letterColor: '',
    },
    {
      backgroundColor: 'b10086',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'M',
      lineNumber: '20',
      lineDescription: 'Nueva Llacolén -  San Pedro Costa',
      letterColor: '',
    },
    {
      backgroundColor: '0071ca',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'A',
      lineNumber: '20',
      lineDescription: 'Nueva Llacolén -  Boca Sur',
      letterColor: '',
    },
    {
      backgroundColor: '0071ca',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'F',
      lineNumber: '24',
      lineDescription: 'San Remo - Candelaria',
      letterColor: '',
    },
    {
      backgroundColor: '0d7215',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'Q',
      lineNumber: '30',
      lineDescription: 'Ruta Las Playas -  Higueras',
      letterColor: '',
    },
    {
      backgroundColor: '049684',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'R',
      lineNumber: '30',
      lineDescription: 'Ruta Las Playas -  Higueras',
      letterColor: '',
    },
    {
      backgroundColor: 'ce5504',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'P',
      lineNumber: '57',
      lineDescription: 'Denavi Sur - San Vicente',
      letterColor: '',
    },
    {
      backgroundColor: 'ad0101',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'D',
      lineNumber: '31',
      lineDescription: 'Ruta del Mar -  Lobos Viejos',
      letterColor: '',
    },
    {
      backgroundColor: 'ad0101',
      estimatedArrivalTimeInMinutes: 'Más de 10 minutos',
      lineLetter: 'G',
      lineNumber: '40',
      lineDescription: 'Las Golondrinas -  Candelaria',
      letterColor: '',
    },
  ],
  lines: [
    {
      lineNumber: 'Vía Láctea 10N - Los Bloques',
      description: '10N',
      locomotionType: 'Autobús',
      backgroundColor: 'b10086',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '21:57:47', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:11:13', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Vía Láctea 10P - Leonera',
      description: '10P',
      locomotionType: 'Autobús',
      backgroundColor: '0071ca',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:11:15', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Vía Láctea 10L -  Los Bloques',
      description: '10L',
      locomotionType: 'Autobús',
      backgroundColor: '4e0963',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:11:15', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Vía Futuro 11Q -  Los Bloques',
      description: '11Q',
      locomotionType: 'Autobús',
      backgroundColor: 'ad0101',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:03:18', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Vía Futuro 11R - Porvenir',
      description: '11R',
      locomotionType: 'Autobús',
      backgroundColor: 'b10086',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:10:32', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '21:58:25', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Vía Siglo XXI 13S - Leonera',
      description: '13S',
      locomotionType: 'Autobús',
      backgroundColor: 'ce5504',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:05:47', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:03:29', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Chiguayante Sur 14T -  Coquimbo',
      description: '14T',
      locomotionType: 'Autobús',
      backgroundColor: 'ce5504',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:03:07', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:10:34', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Chiguayante Sur 14U -  Los Altos',
      description: '14U',
      locomotionType: 'Autobús',
      backgroundColor: 'cc9b00',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '21:58:12', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Vía Universo 16K - Leonera',
      description: '16K',
      locomotionType: 'Autobús',
      backgroundColor: 'ce5504',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '21:56:07', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:03:34', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Vía Universo 16V - Leonera',
      description: '16V',
      locomotionType: 'Autobús',
      backgroundColor: 'ad0101',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '21:55:51', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:03:50', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '21:51:59', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:11:13', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Expresos Chiguayante 17W - Leonera',
      description: '17W',
      locomotionType: 'Autobús',
      backgroundColor: '0d7215',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:10:43', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Expresos Chiguayante 17X - Leonera',
      description: '17X',
      locomotionType: 'Autobús',
      backgroundColor: 'ce5504',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '21:57:13', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:05:42', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '21:54:55', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Buses Palomares 18Y -  Hualqui',
      description: '18Y',
      locomotionType: 'Autobús',
      backgroundColor: '0071ca',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:10:11', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Nueva Llacolén 20M -  San Pedro Costa',
      description: '20M',
      locomotionType: 'Autobús',
      backgroundColor: 'b10086',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:08:19', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Nueva Llacolén 20A -  Boca Sur',
      description: '20A',
      locomotionType: 'Autobús',
      backgroundColor: '0071ca',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '21:55:19', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:09:49', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'San Remo 24F - Candelaria',
      description: '24F',
      locomotionType: 'Autobús',
      backgroundColor: '0071ca',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '21:51:14', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '21:43:17', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Ruta Las Playas 30Q -  Higueras',
      description: '30Q',
      locomotionType: 'Autobús',
      backgroundColor: '0d7215',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:00:38', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Ruta Las Playas 30R -  Higueras',
      description: '30R',
      locomotionType: 'Autobús',
      backgroundColor: '049684',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '21:50:33', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Denavi Sur 57P - San Vicente',
      description: '57P',
      locomotionType: 'Autobús',
      backgroundColor: 'ce5504',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:06:08', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Ruta del Mar 31D -  Lobos Viejos',
      description: '31D',
      locomotionType: 'Autobús',
      backgroundColor: 'ad0101',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:10:32', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:10:34', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:06:41', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Las Golondrinas 40G -  Candelaria',
      description: '40G',
      locomotionType: 'Autobús',
      backgroundColor: 'ad0101',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '21:48:36', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Buses Hualpencillo 42F -  Concepción',
      description: '42F',
      locomotionType: 'Autobús',
      backgroundColor: 'ce5504',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '21:19:33', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Mi Expreso 62M - San Vicente',
      description: '62M',
      locomotionType: 'Autobús',
      backgroundColor: '0071ca',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:02:34', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Pedro de Valdivia 72K -  Lonco',
      description: '72K',
      locomotionType: 'Autobús',
      backgroundColor: '0071ca',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '21:17:38', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '21:26:45', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Nueva Sol Yet 90X - Parque Central',
      description: '90X',
      locomotionType: 'Autobús',
      backgroundColor: 'ad0101',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '21:39:48', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '21:47:30', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '21:52:24', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Biobús B02 - Centro Concepción',
      description: 'B02',
      locomotionType: 'Autobús',
      backgroundColor: '0d7215',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '21:37:33', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Las Bahías 70I -  Centinela',
      description: '70I',
      locomotionType: 'Autobús',
      backgroundColor: '613FA6',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:05:39', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:09:26', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Las Bahías 70J -  Los Copihues',
      description: '70J',
      locomotionType: 'Autobús',
      backgroundColor: 'b38800',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:01:24', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Las Galaxias 80Q -  Hualqui',
      description: '80Q',
      locomotionType: 'Autobús',
      backgroundColor: 'ce5504',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:10:28', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:10:54', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:11:01', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Las Galaxias 80H -  Hualqui',
      description: '80H',
      locomotionType: 'Autobús',
      backgroundColor: '0071ca',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:10:23', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:10:32', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Las Galaxias 80Z -  Valle Piedra',
      description: '80Z',
      locomotionType: 'Autobús',
      backgroundColor: '0d7215',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:06:08', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:10:02', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:11:02', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '21:54:16', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:01:17', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Ruta del Mar 32E -  Lobos Viejos',
      description: '32E',
      locomotionType: 'Autobús',
      backgroundColor: 'b10086',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:05:08', distanceGPS: '', carPlate: ''},
        {planned: '', estimatedGPS: '22:10:28', distanceGPS: '', carPlate: ''},
      ],
    },
    {
      lineNumber: 'Ruta del Mar 32J - Lobos Viejos',
      description: '32J',
      locomotionType: 'Autobús',
      backgroundColor: '598200',
      letterColor: '',
      lineMessage: '',
      arrivals: [
        {planned: '', estimatedGPS: '22:09:44', distanceGPS: '', carPlate: ''},
      ],
    },
  ],
  stopName: "O'Higgins -esq. Salas",
};

describe('BusStopInfoScreen tests', () => {
  beforeAll(() => {
    jest.spyOn(useDevices, 'default').mockReturnValue({
      state: mockState,
    });
    getString.mockReturnValue('https://www.google.com');
  });

  it('should be defined', () => {
    expect(BusStopInfoScreen).toBeDefined();
  });

  it('should render the screen with status loading', () => {
    jest.spyOn(useRemoteConfig, 'default').mockReturnValue({
      status: 0,
    });
    const {toJSON} = render(<BusStopInfoScreen />);

    expect(toJSON()).toMatchSnapshot();
  });

  it('should render the screen with status error', () => {
    jest.spyOn(useRemoteConfig, 'default').mockReturnValue({
      status: 2,
    });

    const {toJSON} = render(<BusStopInfoScreen />);

    expect(toJSON()).toMatchSnapshot();
  });

  it('should render the screen with status success', () => {
    jest.spyOn(useRemoteConfig, 'default').mockReturnValue({
      status: 1,
    });
    const {toJSON} = render(<BusStopInfoScreen />);

    expect(toJSON()).toMatchSnapshot();
  });
});
